@@ -15,6 +15,21 @@ fn main() -> Result<(), Error> {
                 .command("rvim [FILE]...")
                 .output("TODO"),
         )
+        .custom(Section::new("Features").paragraph(
+            r#"Syntax Highlighting:
+    - Bash (.sh)
+    - C (.c, .h)
+    - C++ (.cc, .cpp, .C, .h, .hh, .hpp)
+    - C# (.cs)
+    - Java (.java)
+    - Javascript (.js)
+    - JSON (.json)
+    - Go (.go)
+    - Python (.py)
+    - R (.r)
+    - Ruby (.rb)
+    - Rust (.rs)"#,
+        ))
         .author(Author::new("Takashi I").email("mail@takashiidobe.com"))
         .render();
 
